@@ -1,5 +1,2 @@
-import os
 def logo_allenlib():
-    print('allenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib')
-def make_gui():
-    os.system('1.exe')
\ No newline at end of file
+    print('allenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib')
\ No newline at end of file
